@@ -1,11 +1,6 @@
 from PyObjCTools.TestSupport import *
 from CoreFoundation import *
 
-try:
-    long
-except NameError:
-    long = int
-
 
 class TestCFBag (TestCase):
 
