@@ -4,29 +4,33 @@ from CoreFoundation import *
 import CoreFoundation
 import sys
 
-try:
-    unicode
-except NameError:
-    unicode = str
-
-
-try:
-    long
-except NameError:
-    long = int
-
 try:
     buffer
 except NameError:
     buffer = memoryview
 
+
+cached_info = None
 def onTheNetwork():
+    global cached_info
+    if cached_info is not None:
+        return cached_info
+
     try:
         socket.gethostbyname('www.apple.com')
 
-    except socket.gaierror:
+        sd = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+        sd.settimeout(1.0)
+        try:
+            sd.connect(('www.apple.com', 80))
+        finally:
+            sd.close()
+
+    except socket.error:
+        cached_info = False
         return False
 
+    cached_info = True
     return True
 
 
@@ -78,7 +82,7 @@ class TestSocket (TestCase):
 
         CFSocketSetDefaultNameRegistryPortNumber(p1)
 
-    @onlyIf(onTheNetwork(), "cannot test without internet connection")
+    @onlyIf(onTheNetwork(), "Test requires a working Internet connection")
     def testSocketFunctions(self):
         data = {}
         state = []
@@ -186,7 +190,7 @@ class TestSocket (TestCase):
 
     def testSocketNameServer(self):
         # The documentation says:
-        #   Name server functionality is currently inoperable in Mac OS X.
+        #   Name server functionality is currently inoperable in macOS.
         #
         # Therefore these functions are not available from Python
         self.assertNotHasAttr(CoreFoundation, 'CFSocketCopyRegisteredSocketSignature')
