@@ -2,11 +2,6 @@ from PyObjCTools.TestSupport import *
 from CoreFoundation import *
 
 
-try:
-    long
-except NameError:
-    long = int
-
 
 class TestXMLNode (TestCase):
     # NOTE: This doesn't actually test the API
@@ -86,6 +81,10 @@ class TestXMLNode (TestCase):
 
         self.assertResultIsCFRetained(CFXMLNodeCreateCopy)
         self.assertResultIsCFRetained(CFXMLTreeCreateWithNode)
+        CFXMLNodeGetTypeCode
+        CFXMLNodeGetString
+        CFXMLNodeGetVersion
+        CFXMLTreeGetNode
 
     @expectedFailure
     def testMissingWrappers(self):
