@@ -2,46 +2,28 @@
 from PyObjCTools.TestSupport import *
 from AppKit import *
 
-try:
-    unicode
-except NameError:
-    unicode = str
-
-
-try:
-    long
-except NameError:
-    long = int
 
 class TestNSApplicationHelper (NSObject):
-    def copyWithZone_(self, zone):
-        return self
-
-    def writeSelectionToPasteboard_types_(self, pb, tp):
-        return 1
-    def readSelectionFromPasteboard_(self, pb):
-        return 1
-    def application_openFile_(self, sender, file):
-        return 1
-    def application_openTempFile_(self, sender, file):
-        return 1
-    def applicationShouldOpenUntitledFile_(self, sender):
-        return 1
-    def application_openFileWithoutUI_(self, sender, file):
-        return 1
-    def application_printFile_(self, sender, file):
-        return 1
-    def application_printFiles_withSettings_showPrintPanels_(
-            self, a, f, s, sh):
-        return 1
-    def applicationShouldTerminateAfterLastWindowClosed_(self, sender):
-        return 1
-    def applicationShouldHandleReopen_hasVisibleWindows_(self, sender, flag):
-        return 1
+    def copyWithZone_(self, zone): return self
+    def writeSelectionToPasteboard_types_(self, pb, tp): return 1
+    def readSelectionFromPasteboard_(self, pb): return 1
+    def application_openFile_(self, sender, file): return 1
+    def application_openTempFile_(self, sender, file): return 1
+    def applicationShouldOpenUntitledFile_(self, sender): return 1
+    def application_openFileWithoutUI_(self, sender, file): return 1
+    def application_printFile_(self, sender, file): return 1
+    def application_printFiles_withSettings_showPrintPanels_(self, a, f, s, sh): return 1
+    def applicationShouldTerminateAfterLastWindowClosed_(self, sender): return 1
+    def applicationShouldHandleReopen_hasVisibleWindows_(self, sender, flag): return 1
+    def application_willContinueUserActivityWithType_(self, sender, tp): return 1
+    def application_continueUserActivity_restorationHandler_(self, sender, tp, h): return 1
+    def application_delegateHandlesKey_(self, a, k): return 1
 
 
 class TestNSApplication (TestCase):
     def testConstants(self):
+        self.assertIsInstance(NSAppKitVersionNumber, float)
+
         self.assertEqual(NSAppKitVersionNumber10_0, 577)
         self.assertEqual(NSAppKitVersionNumber10_1, 620)
         self.assertEqual(NSAppKitVersionNumber10_2, 663)
@@ -61,6 +43,29 @@ class TestNSApplication (TestCase):
         self.assertEqual(NSAppKitVersionNumber10_5_2, 949.27)
         self.assertEqual(NSAppKitVersionNumber10_5_3, 949.33)
         self.assertEqual(NSAppKitVersionNumber10_6, 1038)
+        self.assertEqual(NSAppKitVersionNumber10_7, 1138)
+        self.assertEqual(NSAppKitVersionNumber10_7_2, 1138.23)
+        self.assertEqual(NSAppKitVersionNumber10_7_3, 1138.32)
+        self.assertEqual(NSAppKitVersionNumber10_7_4, 1138.47)
+        self.assertEqual(NSAppKitVersionNumber10_8, 1187)
+        self.assertEqual(NSAppKitVersionNumber10_9, 1265)
+        self.assertEqual(NSAppKitVersionNumber10_10, 1343)
+        self.assertEqual(NSAppKitVersionNumber10_10_2, 1344)
+        self.assertEqual(NSAppKitVersionNumber10_10_3, 1347)
+        self.assertEqual(NSAppKitVersionNumber10_10_4, 1348)
+        self.assertEqual(NSAppKitVersionNumber10_10_5, 1348)
+        self.assertEqual(NSAppKitVersionNumber10_10_Max, 1349)
+        self.assertEqual(NSAppKitVersionNumber10_11, 1404)
+        self.assertEqual(NSAppKitVersionNumber10_11_1, 1404.13)
+        self.assertEqual(NSAppKitVersionNumber10_11_2, 1404.34)
+        self.assertEqual(NSAppKitVersionNumber10_11_3, 1404.34)
+        self.assertEqual(NSAppKitVersionNumber10_12, 1504)
+        self.assertEqual(NSAppKitVersionNumber10_12_1, 1504.60)
+        self.assertEqual(NSAppKitVersionNumber10_12_2, 1504.76)
+        self.assertEqual(NSAppKitVersionNumber10_13, 1561)
+        self.assertEqual(NSAppKitVersionNumber10_13_1, 1561.1)
+        self.assertEqual(NSAppKitVersionNumber10_13_2, 1561.2)
+        self.assertEqual(NSAppKitVersionNumber10_13_4, 1561.4)
 
 
         self.assertIsInstance(NSModalPanelRunLoopMode, unicode)
@@ -103,6 +108,8 @@ class TestNSApplication (TestCase):
         self.assertIsInstance(NSApplicationWillTerminateNotification, unicode)
         self.assertIsInstance(NSApplicationDidChangeScreenParametersNotification, unicode)
 
+        self.assertEqual(NSWindowListOrderedFrontToBack, 1<<0)
+
 
     def testFunctions(self):
         # Testing the next function is not doable in this context...
@@ -123,7 +130,7 @@ class TestNSApplication (TestCase):
         self.assertIsInstance(NSPerformService("help", pboard), bool)
 
         v = TestNSApplicationHelper.alloc().init()
-        NSRegisterServicesProvider("foobar", v)
+        NSRegisterServicesProvider(v, "foobar")
         NSUnregisterServicesProvider("foobar")
 
     def testNSApp(self):
@@ -134,6 +141,10 @@ class TestNSApplication (TestCase):
         if app is not None:
             self.assertIsInstance(app, NSApplication)
 
+            self.assertIsInstance(NSApp.description(), unicode)
+
+            self.assertRaises(AttributeError, setattr, NSApp, 'foo', 42)
+
     def testNSModalSession(self):
         self.assertIsOpaquePointer(NSModalSession)
 
@@ -162,6 +173,8 @@ class TestNSApplication (TestCase):
         self.assertArgIsBOOL(NSApplication.addWindowsItem_title_filename_, 2)
         self.assertArgIsBOOL(NSApplication.changeWindowsItem_title_filename_, 2)
 
+        self.assertArgIsBOOL(NSApplication.nextEventMatchingMask_untilDate_inMode_dequeue_, 3)
+
     def testDelegateMethods(self):
         self.assertResultIsBOOL(TestNSApplicationHelper.application_openFile_)
         self.assertResultIsBOOL(TestNSApplicationHelper.application_openTempFile_)
@@ -176,6 +189,12 @@ class TestNSApplication (TestCase):
         self.assertResultIsBOOL(TestNSApplicationHelper.writeSelectionToPasteboard_types_)
         self.assertResultIsBOOL(TestNSApplicationHelper.readSelectionFromPasteboard_)
 
+        self.assertResultIsBOOL(TestNSApplicationHelper.application_willContinueUserActivityWithType_)
+        self.assertResultIsBOOL(TestNSApplicationHelper.application_continueUserActivity_restorationHandler_)
+        self.assertArgIsBlock(TestNSApplicationHelper.application_continueUserActivity_restorationHandler_, 2, b'v@')
+
+        self.assertResultIsBOOL(TestNSApplicationHelper.application_delegateHandlesKey_)
+
 
     @min_os_level('10.6')
     def testConstants10_6(self):
@@ -225,11 +244,45 @@ class TestNSApplication (TestCase):
         self.assertEqual(NSRemoteNotificationTypeSound, 2)
         self.assertEqual(NSRemoteNotificationTypeAlert, 4)
 
+    @min_os_level('10.9')
+    def testConstants10_9(self):
+        self.assertEqual(NSApplicationOcclusionStateVisible, 1 << 1)
+
+        self.assertIsInstance(NSApplicationDidChangeOcclusionStateNotification, unicode)
+
+    @min_os_level('10.11')
+    def testConstants10_11(self):
+        self.assertEqual(NSApplicationPresentationDisableCursorLocationAssistance, 1 << 12)
+
+    @min_os_level('10.13')
+    def testConstants10_13(self):
+        self.assertIsInstance(NSAboutPanelOptionCredits, unicode)
+        self.assertIsInstance(NSAboutPanelOptionApplicationName, unicode)
+        self.assertIsInstance(NSAboutPanelOptionApplicationIcon, unicode)
+        self.assertIsInstance(NSAboutPanelOptionVersion, unicode)
+        self.assertIsInstance(NSAboutPanelOptionApplicationVersion, unicode)
+
+    @min_os_level('10.14')
+    def testConstants10_14(self):
+        self.assertIsInstance(NSAppearanceDocumentAttribute, unicode)
+
     @min_os_level('10.6')
     def testMethods10_6(self):
         self.assertResultIsBOOL(NSApplication.setActivationPolicy_)
         self.assertResultIsBOOL(NSApplication.isFullKeyboardAccessEnabled)
 
+    @min_os_level('10.12')
+    def testMethods10_12(self):
+        self.assertArgIsBlock(NSApplication.enumerateWindowsWithOptions_usingBlock_, 1, b'v@o^Z')
+
+    @min_os_level('10.14')
+    def testMethods10_12(self):
+        self.assertResultIsBOOL(NSApplication.isRegisteredForRemoteNotifications)
+
+    @min_sdk_level('10.10')
+    def testProtocols(self):
+        objc.protocolNamed("NSApplicationDelegate")
+
 
 
 if __name__ == "__main__":
