@@ -9,5 +9,10 @@ class TestNSClipView (TestCase):
         self.assertArgIsBOOL(NSClipView.setCopiesOnScroll_, 0)
         self.assertResultIsBOOL(NSClipView.autoscroll_)
 
+    @min_os_level('10.10')
+    def testMethods10_10(self):
+        self.assertResultIsBOOL(NSClipView.automaticallyAdjustsContentInsets)
+        self.assertArgIsBOOL(NSClipView.setAutomaticallyAdjustsContentInsets_, 0)
+
 if __name__ == "__main__":
     main()
