@@ -2,20 +2,15 @@ from PyObjCTools.TestSupport import *
 import sys
 from Foundation import *
 
-try:
-    unicode
-except NameError:
-    unicode = str
-
-
-try:
-    long
-except NameError:
-    long = int
 
 
 class TestNSObjCRuntime (TestCase):
     def testConstants(self):
+        self.assertEqual(NSQualityOfServiceUserInteractive, 0x21)
+        self.assertEqual(NSQualityOfServiceUserInitiated, 0x19)
+        self.assertEqual(NSQualityOfServiceUtility, 0x11)
+        self.assertEqual(NSQualityOfServiceBackground, 0x09)
+        self.assertEqual(NSQualityOfServiceDefault, -1)
         self.assertEqual(NSFoundationVersionNumber10_0,   397.40)
         self.assertEqual(NSFoundationVersionNumber10_1,   425.00)
         self.assertEqual(NSFoundationVersionNumber10_1_1, 425.00)
@@ -52,23 +47,47 @@ class TestNSObjCRuntime (TestCase):
         self.assertEqual(NSFoundationVersionNumber10_4_7, 567.27)
         self.assertEqual(NSFoundationVersionNumber10_4_8, 567.28)
         self.assertEqual(NSFoundationVersionNumber10_4_9, 567.29)
-        self.assertEqual(NSFoundationVersionNumber10_4_10,        567.29)
-        self.assertEqual(NSFoundationVersionNumber10_4_11,        567.36)
-        self.assertEqual( NSFoundationVersionNumber10_5, 677.00)
-        self.assertEqual( NSFoundationVersionNumber10_5_1, 677.10)
-        self.assertEqual( NSFoundationVersionNumber10_5_2, 677.15)
-        self.assertEqual( NSFoundationVersionNumber10_5_3, 677.19)
-        self.assertEqual( NSFoundationVersionNumber10_5_4, 677.19)
-        self.assertEqual( NSFoundationVersionNumber10_5_5, 677.21)
-        self.assertEqual( NSFoundationVersionNumber10_5_6, 677.22)
-        self.assertEqual( NSFoundationVersionNumber10_5_7, 677.24)
-        self.assertEqual( NSFoundationVersionNumber10_5_8, 677.26)
-        self.assertEqual( NSFoundationVersionNumber10_6, 751.00)
-        self.assertEqual( NSFoundationVersionNumber10_6_1, 751.00)
-        self.assertEqual( NSFoundationVersionNumber10_6_2, 751.14)
-        self.assertEqual( NSFoundationVersionNumber10_6_3, 751.21)
-        self.assertEqual( NSFoundationVersionNumber10_6_4, 751.29)
-        self.assertEqual( NSFoundationVersionNumber10_6_5, 751.42)
+        self.assertEqual(NSFoundationVersionNumber10_4_10, 567.29)
+        self.assertEqual(NSFoundationVersionNumber10_4_11, 567.36)
+        self.assertEqual(NSFoundationVersionNumber10_5, 677.00)
+        self.assertEqual(NSFoundationVersionNumber10_5_1, 677.10)
+        self.assertEqual(NSFoundationVersionNumber10_5_2, 677.15)
+        self.assertEqual(NSFoundationVersionNumber10_5_3, 677.19)
+        self.assertEqual(NSFoundationVersionNumber10_5_4, 677.19)
+        self.assertEqual(NSFoundationVersionNumber10_5_5, 677.21)
+        self.assertEqual(NSFoundationVersionNumber10_5_6, 677.22)
+        self.assertEqual(NSFoundationVersionNumber10_5_7, 677.24)
+        self.assertEqual(NSFoundationVersionNumber10_5_8, 677.26)
+        self.assertEqual(NSFoundationVersionNumber10_6, 751.00)
+        self.assertEqual(NSFoundationVersionNumber10_6_1, 751.00)
+        self.assertEqual(NSFoundationVersionNumber10_6_2, 751.14)
+        self.assertEqual(NSFoundationVersionNumber10_6_3, 751.21)
+        self.assertEqual(NSFoundationVersionNumber10_6_4, 751.29)
+        self.assertEqual(NSFoundationVersionNumber10_6_5, 751.42)
+        self.assertEqual(NSFoundationVersionNumber10_6_6, 751.53)
+        self.assertEqual(NSFoundationVersionNumber10_6_7, 751.53)
+        self.assertEqual(NSFoundationVersionNumber10_6_8, 751.62)
+        self.assertEqual(NSFoundationVersionNumber10_8, 945.00)
+        self.assertEqual(NSFoundationVersionNumber10_8_1, 945.00)
+        self.assertEqual(NSFoundationVersionNumber10_8_2, 945.11)
+        self.assertEqual(NSFoundationVersionNumber10_8_3, 945.16)
+        self.assertEqual(NSFoundationVersionNumber10_8_4, 945.18)
+        self.assertEqual(NSFoundationVersionNumber10_9, 1056)
+        self.assertEqual(NSFoundationVersionNumber10_9_1, 1056)
+        self.assertEqual(NSFoundationVersionNumber10_9_2, 1056.13)
+        self.assertEqual(NSFoundationVersionNumber10_10, 1151.16)
+        self.assertEqual(NSFoundationVersionNumber10_10_1, 1151.16)
+        self.assertEqual(NSFoundationVersionNumber10_10_2, 1152.14)
+        self.assertEqual(NSFoundationVersionNumber10_10_3, 1153.20)
+        self.assertEqual(NSFoundationVersionNumber10_10_4, 1153.20)
+        self.assertEqual(NSFoundationVersionNumber10_10_5, 1154)
+        self.assertEqual(NSFoundationVersionNumber10_10_Max, 1199)
+        self.assertEqual(NSFoundationVersionNumber10_11,   1252)
+        self.assertEqual(NSFoundationVersionNumber10_11_1, 1255.1)
+        self.assertEqual(NSFoundationVersionNumber10_11_2, 1256.1)
+        self.assertEqual(NSFoundationVersionNumber10_11_3, 1256.1)
+        self.assertEqual(NSFoundationVersionNumber10_11_4, 1258)
+        self.assertEqual(NSFoundationVersionNumber10_11_Max, 1299)
 
 
         self.assertIsInstance(NSFoundationVersionNumber, float)
@@ -150,9 +169,12 @@ class TestNSObjCRuntime (TestCase):
 
     def testMinMax(self):
         self.assertEqual(MAX(1, 2), 2)
+        self.assertEqual(MAX(2, 1), 2)
         self.assertEqual(MAX("a", "b"), "b")
         self.assertEqual(MIN(1, 2), 1)
+        self.assertEqual(MIN(2, 1), 1)
         self.assertEqual(MIN("a", "b"), "a")
+        self.assertEqual(ABS(1), 1)
         self.assertEqual(ABS(-1), 1)
         self.assertEqual(ABS(-1.0), 1.0)
 
